@@ -3,7 +3,7 @@ from .third_party_api import (
     OSDataHubNamesAPIParsingHandler,
     PostcodesIOAPIParsingHandler,
 )
-from .onspd_csv_file import ONSPDCsvFileParsingHandler
+from .onspd_csv_file import ONSPDCSVFileParsingHandler
 from .regex import RegexParsingHandler
 
 
@@ -11,6 +11,6 @@ __all__ = [
     "ParsingHandler",
     "OSDataHubNamesAPIParsingHandler",
     "PostcodesIOAPIParsingHandler",
-    "ONSPDCsvFileParsingHandler",
+    "ONSPDCSVFileParsingHandler",
     "RegexParsingHandler",
 ]
